/**
 * Licensed to Cloudera, Inc. under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  Cloudera, Inc. licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudera.flume.reporter;

import java.util.Map;

/**
 * Any statistics presenting element will implement this interface. These should
 * be registered to the ReporterManager so that they can be displayed.
 */
public interface Reportable {

  /**
   * This the name of the report. Will be used in charts.
   */
  String getName();

  /**
   * Generates a report in some sort of readable format.
   */
  ReportEvent getMetrics();

  /**
   * Get child reportables.
   */
  Map<String, Reportable> getSubMetrics();

}
